@@ -1,14 +1,11 @@
-import io
-import os
-import sys
-import logging
 import argparse
+import logging
+import sys
 import warnings
+
 from decli import cli
-from pathlib import Path
-from configparser import RawConfigParser, NoSectionError
-from commitizen import defaults, commands, out, config
-from commitizen.__version__ import __version__
+
+from commitizen import commands, config, out
 
 
 logger = logging.getLogger(__name__)
@@ -31,6 +28,8 @@ data = {
     ],
     "subcommands": {
         "title": "commands",
+        # TODO: Add this constraint back in 2.0
+        # "required": True,
         "commands": [
             {
                 "name": "ls",
@@ -47,7 +46,12 @@ data = {
                         "action": "store_true",
                         "help": "retry last commit",
                     },
-                ]
+                    {
+                        "name": "--dry-run",
+                        "action": "store_true",
+                        "help": "show output to stdout, no commit, no modified files",
+                    },
+                ],
             },
             {
                 "name": "example",
@@ -102,6 +106,26 @@ data = {
                     },
                 ],
             },
+            {
+                "name": ["version"],
+                "help": "get the version of the installed commitizen",
+                "func": commands.Version,
+            },
+            {
+                "name": ["check"],
+                "help": "enforce the project to always use conventional commits",
+                "func": commands.Check,
+                "arguments": [
+                    {
+                        "name": "--commit-msg-file",
+                        "help": (
+                            "ask for the name of the temporal file that contains "
+                            "the commit message. "
+                            "Using it in a git hook script: MSG_FILE=$1"
+                        ),
+                    }
+                ],
+            },
         ],
     },
 }
@@ -116,11 +140,22 @@ def main():
         parser.print_help(sys.stderr)
         raise SystemExit()
 
-    args = parser.parse_args()
+    try:
+        args = parser.parse_args()
+    except TypeError:
+        out.error("Command is required")
+        raise SystemExit()
 
     if args.name:
         conf.update({"name": args.name})
 
+    if args.version:
+        warnings.warn(
+            "'cz --version' will be deprecated in next major version. "
+            "Please use 'cz version' command from your scripts"
+        )
+        logging.getLogger("commitizen").setLevel(logging.DEBUG)
+
     if args.debug:
         warnings.warn(
             "Debug will be deprecated in next major version. "
@@ -128,8 +163,8 @@ def main():
         )
         logging.getLogger("commitizen").setLevel(logging.DEBUG)
 
-    if args.version:
-        out.line(__version__)
-        raise SystemExit()
-
-    args.func(conf, vars(args))()
+    # TODO: This try block can be removed after command is required in 2.0
+    try:
+        args.func(conf, vars(args))()
+    except AttributeError:
+        out.error("Command is required")
