@@ -1,8 +1,11 @@
 from .bump import Bump
 from .commit import Commit
+from .check import Check
 from .example import Example
 from .info import Info
 from .list_cz import ListCz
 from .schema import Schema
+from .version import Version
 
-__all__ = ("Bump", "Commit", "Example", "Info", "ListCz", "Schema")
+__all__ = ("Bump", "Check", "Commit", "Example", "Info", "ListCz", "Schema",
+           "Version")
