@@ -1,8 +1,9 @@
-from packaging.version import Version
 from typing import Optional
 
 import questionary
-from commitizen import bump, git, config, out, factory
+from packaging.version import Version
+
+from commitizen import bump, config, factory, git, out
 
 NO_COMMITS_FOUND = 3
 NO_VERSION_SPECIFIED = 4
@@ -121,7 +122,7 @@ class Bump:
         bump.update_version_in_files(current_version, new_version.public, files)
         c = git.commit(message, args="-a")
         if c.err:
-            out.error(c.err)
+            out.error('git.commit errror: "{}"'.format(c.err.strip()))
             raise SystemExit(COMMIT_FAILED)
         c = git.tag(new_tag_version)
         if c.err:
