@@ -1,6 +1,6 @@
 import os
-from commitizen.cz.base import BaseCommitizen
 
+from commitizen.cz.base import BaseCommitizen
 
 __all__ = ["JiraSmartCz"]
 
@@ -67,7 +67,7 @@ class JiraSmartCz(BaseCommitizen):
         )
 
     def schema(self):
-        return "<ignored text> <ISSUE_KEY> <ignored text> #<COMMAND> <optional COMMAND_ARGUMENTS>"
+        return "<ignored text> <ISSUE_KEY> <ignored text> #<COMMAND> <optional COMMAND_ARGUMENTS>"  # noqa
 
     def info(self):
         dir_path = os.path.dirname(os.path.realpath(__file__))
